@@ -262,15 +262,18 @@ sub _pack {
         return $header . $value;
 
     }
-    if ( $flags & B::SVf_IOK ) {
-        if ($value >= 0) {
+    elsif( $flags & B::SVp_NOK ) { # double only
+        return pack_double( $value );
+    }
+    elsif ( $flags & B::SVp_IOK ) {
+        if ($value >= 0) { # UV
             return    $value <= 127 ?    CORE::pack 'C',        $value
-                    : $value < 2 ** 8 ?  CORE::pack 'CC', 0xcc, $value
+                    : $value < 2 **  8 ? CORE::pack 'CC', 0xcc, $value
                     : $value < 2 ** 16 ? CORE::pack 'Cn', 0xcd, $value
                     : $value < 2 ** 32 ? CORE::pack 'CN', 0xce, $value
                     : pack_uint64( $value );
         }
-        else {
+        else { # IV
             return    -$value <= 32 ?      CORE::pack 'C', ($value & 255)
                     : -$value <= 2 **  7 ? CORE::pack 'Cc', 0xd0, $value
                     : -$value <= 2 ** 15 ? CORE::pack 'Cn', 0xd1, $value
@@ -278,9 +281,6 @@ sub _pack {
                     : pack_int64( $value );
         }
     }
-    elsif ( $flags & B::SVf_NOK ) { # double only
-        return pack_double( $value );
-    }
     else {
         _unexpected("data type %s", $b_obj);
     }
@@ -461,6 +461,7 @@ package
     Data::MessagePack::PP::Unpacker;
 
 sub new {
+    warn "Data::MessagePack::Unpacker was deprecated. Use Data::MessagePack::Stream instead.";
     bless {
         pos  => 0,
         utf8 => 0,
@@ -484,6 +485,7 @@ sub execute_limit {
 }
 
 sub execute {
+    warn "Data::MessagePack::Unpacker was deprecated. Use Data::MessagePack::Stream instead.";
     my ( $self, $data, $offset, $limit ) = @_;
     $offset ||= 0;
     my $value = substr( $data, $offset, $limit ? $limit : length $data );
@@ -613,17 +615,20 @@ sub _count {
 
 sub data {
     my($self) = @_;
+    warn "Data::MessagePack::Unpacker was deprecated. Use Data::MessagePack::Stream instead.";
     local $Data::MessagePack::PP::_utf8 = $self->{utf8};
     return Data::MessagePack->unpack( substr($self->{buff}, 0, $self->{pos}) );
 }
 
 
 sub is_finished {
+    warn "Data::MessagePack::Unpacker was deprecated. Use Data::MessagePack::Stream instead.";
     my ( $self ) = @_;
     return $self->{is_finished};
 }
 
 sub reset :method {
+    warn "Data::MessagePack::Unpacker was deprecated. Use Data::MessagePack::Stream instead.";
     $_[0]->{buff}        = '';
     $_[0]->{pos}         = 0;
     $_[0]->{is_finished} = 0;
